@@ -334,6 +334,21 @@ read_twix <- function(fname, verbose, full_fid = FALSE,
                ChemicalShiftReference = 4.7 + vars$delta_freq,
                NumberOfTransients = vars$averages,
                Manufacturer = "Siemens")
+  
+  if (toupper(vars$seq_fname) == "%SIEMENSSEQ%\\SVS_SE") {
+    meta <- append(meta, list(PulseSequenceType = "press"))
+  }
+  
+  if (toupper(vars$seq_fname) == "%SIEMENSSEQ%\\SVS_ST") {
+    meta <- append(meta, list(PulseSequenceType = "steam"))
+  }
+  
+  if (startsWith(toupper(vars$seq_fname), "%CUSTOMERSEQ%\\SVS_SLASER")) {
+    meta <- append(meta, list(PulseSequenceType = "slaser",
+                              TE1 = vars$te1,
+                              TE2 = vars$te2,
+                              TE3 = vars$te3))
+  }
 
   mrs_data <- mrs_data(data = data, ft = vars$ft, resolution = paras$res,
                        ref = paras$ref, nuc = paras$nuc,
@@ -501,11 +516,14 @@ read_siemens_txt_hdr <- function(input, version = "vd", verbose,
     } else if (startsWith(line, "sTXSPEC.asNucleusInfo[0].lFrequency")) {
       vars$ft <- as.numeric(strsplit(line, "=")[[1]][2])
     } else if (startsWith(line, "alTE[0]")) {
-      vars$te <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te  <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te1 <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
     } else if (startsWith(line, "alTE[1]")) {
-      vars$te <- vars$te + (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te  <- vars$te + (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te2 <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
     } else if (startsWith(line, "alTE[2]")) {
-      vars$te <- vars$te + (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te  <- vars$te + (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+      vars$te3 <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
     } else if (startsWith(line, "alTR[0]")) {
       vars$tr <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
     } else if (startsWith(line, "adFlipAngleDegree[0]")) {
